summaryrefslogtreecommitdiff
path: root/hurd/shared.h
diff options
context:
space:
mode:
Diffstat (limited to 'hurd/shared.h')
-rw-r--r--hurd/shared.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/hurd/shared.h b/hurd/shared.h
index 22a3c5f3..988472c1 100644
--- a/hurd/shared.h
+++ b/hurd/shared.h
@@ -23,16 +23,16 @@ struct shared_io
{
int shared_page_magic;
/* This lock protects against modification to it_status. */
spin_lock_t lock;
enum
{
- USER_IT, /* User is it */
- USER_POTENTIALLY_IT, /* User can become it */
- USER_RELEASE_IT, /* User is it, should release it promptly */
- USER_NOT_IT, /* User is not it */
- } it_status;
+ USER_HAS_CONCH, /* User is it */
+ USER_COULD_HAVE_CONCH,, /* User can become it */
+ USER_RELEASE_CONCH, /* User is it, should release it promptly */
+ USER_HAS_NOT_CONCH,, /* User is not it */
+ } conch_status;
/* These values are set by the IO server only: */
@@ -23,16 +23,16 @@ struct shared_io
{
int shared_page_magic;
- /* This lock protects against modification to it_status. */
+ /* This lock protects against modification to conch_status. */
spin_lock_t lock;
enum